[med-svn] samtools 04/26: Merge branch master of git://github.com/leecbaker/samtools
Charles Plessy
plessy at moszumanska.debian.org
Tue Dec 10 10:06:25 UTC 2013
This is an automated email from the git hooks/post-receive script.
plessy pushed a commit to branch debian/unstable
in repository samtools.
commit 92a1cb3d57e0689e051931407037d45462f46b20
Merge: d0ebd20 4ce9296
Author: John Marshall <jm18 at sanger.ac.uk>
Date: Fri Nov 22 17:15:36 2013 +0000
Merge branch master of git://github.com/leecbaker/samtools
Some of the files in the original PR have moved to the bcftools repository,
and the remaining type mismatches of this kind have been fixed there.
bam2bcf_indel.c | 2 +-
bam2depth.c | 4 ++--
bam_lpileup.c | 2 +-
bam_plcmd.c | 8 ++++----
bam_sort.c | 4 ++--
bamshuf.c | 4 ++--
bedcov.c | 6 +++---
kprobaln.c | 4 ++--
phase.c | 8 ++++----
sam_header.c | 2 +-
sample.c | 2 +-
11 files changed, 23 insertions(+), 23 deletions(-)
diff --cc bam_plcmd.c
index 74034f1,ee4a151..eb56253
--- a/bam_plcmd.c
+++ b/bam_plcmd.c
@@@ -254,22 -203,16 +254,22 @@@ static int mpileup(mplp_conf_t *conf, i
memset(&gplp, 0, sizeof(mplp_pileup_t));
memset(&buf, 0, sizeof(kstring_t));
memset(&bc, 0, sizeof(bcf_call_t));
- data = calloc(n, sizeof(void*));
- plp = calloc(n, sizeof(void*));
- n_plp = calloc(n, sizeof(int*));
+ data = calloc(n, sizeof(mplp_aux_t*));
+ plp = calloc(n, sizeof(bam_pileup1_t*));
+ n_plp = calloc(n, sizeof(int));
sm = bam_smpl_init();
- // read the header and initialize data
+ if (n == 0) {
+ fprintf(stderr,"[%s] no input file/data given\n", __func__);
+ exit(1);
+ }
+
+ // read the header of each file in the list and initialize data
for (i = 0; i < n; ++i) {
- bam_header_t *h_tmp;
+ bam_hdr_t *h_tmp;
data[i] = calloc(1, sizeof(mplp_aux_t));
- data[i]->fp = strcmp(fn[i], "-") == 0? bam_dopen(fileno(stdin), "r") : bam_open(fn[i], "r");
+ data[i]->fp = sam_open(fn[i], "rb");
+ hts_set_fai_filename(data[i]->fp, conf->fai_fname);
if ( !data[i]->fp )
{
fprintf(stderr, "[%s] failed to open %s: %s\n", __func__, fn[i], strerror(errno));
--
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/debian-med/samtools.git
More information about the debian-med-commit
mailing list